PALM-meteo: palmmeteo.utils.DTIndexer Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | List of all members
palmmeteo.utils.DTIndexer Class Reference
Collaboration diagram for palmmeteo.utils.DTIndexer:
[legend]

## Public Member Functions
| __call__ (self, dt)

## Public Attributes
| origin
| timestep

## Static Public Attributes
datetime | origin .datetime
datetime | timestep .timedelta

## Detailed Description

    Calculates integral time index from start and origin. Avoids
    using the unpicklable lambdas.

## Member Function Documentation

## ◆ __call__()

palmmeteo.utils.DTIndexer.__call__ | ( |  | self,
|  |  | dt
| ) |  |

## Member Data Documentation

## ◆ origin [1/2]

datetime palmmeteo.utils.DTIndexer.origin .datetime
| static

## ◆ origin [2/2]

palmmeteo.utils.DTIndexer.origin

## ◆ timestep [1/2]

datetime palmmeteo.utils.DTIndexer.timestep .timedelta
| static

## ◆ timestep [2/2]

palmmeteo.utils.DTIndexer.timestep

The documentation for this class was generated from the following file:

- palmmeteo/utils.py